var indexSectionsWithContent =
{
  0: "_abcdefghijklmnopqrstuvwy",
  1: "abcdghjklmopqrstuwy",
  2: "pu",
  3: "_cdfgopsuw",
  4: "_abcdefghiklmnoprstuvw",
  5: "_abcdefghilmnoprstuwy",
  6: "t"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Pages"
};

